@@ -2,10 +2,7 @@
 
 import os
 
-import six
-
 import cherrypy
-from cherrypy._cpcompat import ntou
 from cherrypy import _cpconfig, _cplogging, _cprequest, _cpwsgi, tools
 from cherrypy.lib import httputil, reprconf
 
@@ -82,7 +79,7 @@ class Application(object):
     """
 
     @property
-    def script_name(self):
+    def script_name(self):  # noqa: D401; irrelevant for properties
         """The URI "mount point" for this app.
 
         A mount point is that portion of the URI which is constant for all URIs
@@ -261,7 +258,7 @@ class Tree(object):
         self.apps[script_name] = wsgi_callable
 
     def script_name(self, path=None):
-        """The script_name of the app at the given path, or None.
+        """Return the script_name of the app at the given path, or None.
 
         If path is None, cherrypy.request is used.
         """
@@ -289,8 +286,6 @@ class Tree(object):
         # to '' (some WSGI servers always set SCRIPT_NAME to '').
         # Try to look up the app using the full path.
         env1x = environ
-        if six.PY2 and environ.get(ntou('wsgi.version')) == (ntou('u'), 0):
-            env1x = _cpwsgi.downgrade_wsgi_ux_to_1x(environ)
         path = httputil.urljoin(env1x.get('SCRIPT_NAME', ''),
                                 env1x.get('PATH_INFO', ''))
         sn = self.script_name(path or '/')
@@ -302,12 +297,6 @@ class Tree(object):
 
         # Correct the SCRIPT_NAME and PATH_INFO environ entries.
         environ = environ.copy()
-        if six.PY2 and environ.get(ntou('wsgi.version')) == (ntou('u'), 0):
-            # Python 2/WSGI u.0: all strings MUST be of type unicode
-            enc = environ[ntou('wsgi.url_encoding')]
-            environ[ntou('SCRIPT_NAME')] = sn.decode(enc)
-            environ[ntou('PATH_INFO')] = path[len(sn.rstrip('/')):].decode(enc)
-        else:
-            environ['SCRIPT_NAME'] = sn
-            environ['PATH_INFO'] = path[len(sn.rstrip('/')):]
+        environ['SCRIPT_NAME'] = sn
+        environ['PATH_INFO'] = path[len(sn.rstrip('/')):]
         return app(environ, start_response)
